

Conf
============

.. currentmodule:: webbpsf

.. autoclass:: Conf
   :show-inheritance:

   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~Conf.WEBBPSF_PATH
      ~Conf.default_fov_arcsec
      ~Conf.default_output_mode
      ~Conf.default_oversampling
      ~Conf.last_version_ran
      ~Conf.logging_filename
      ~Conf.logging_level

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: WEBBPSF_PATH
   .. autoattribute:: default_fov_arcsec
   .. autoattribute:: default_output_mode
   .. autoattribute:: default_oversampling
   .. autoattribute:: last_version_ran
   .. autoattribute:: logging_filename
   .. autoattribute:: logging_level

   
   

   
   
   